summaryrefslogtreecommitdiffstats
path: root/BaseTools/Source/Python/BPDG
diff options
context:
space:
mode:
authorGary Lin <glin@suse.com>2018-06-25 18:31:36 +0800
committerYonghong Zhu <yonghong.zhu@intel.com>2018-06-27 16:33:28 +0800
commit86379ac48ba17c71d4623c57099b064b15118e21 (patch)
tree9ec107c195a28a4bdcf9b4734fa2c20b8c07ce32 /BaseTools/Source/Python/BPDG
parent0d1f5b2b5dc3c1cf381be0a1ec8f960dc6029a93 (diff)
downloadedk2-86379ac48ba17c71d4623c57099b064b15118e21.tar.gz
edk2-86379ac48ba17c71d4623c57099b064b15118e21.tar.bz2
edk2-86379ac48ba17c71d4623c57099b064b15118e21.zip
BaseTools: Replace StringIO.StringIO with io.BytesIO
Replace StringIO.StringIO with io.BytesIO to be compatible with python3. This commit also removes "import StringIO" from those python scripts that don't really use it. Contributed-under: TianoCore Contribution Agreement 1.1 Cc: Yonghong Zhu <yonghong.zhu@intel.com> Cc: Liming Gao <liming.gao@intel.com> Signed-off-by: Gary Lin <glin@suse.com> Reviewed-by: Yonghong Zhu <yonghong.zhu@intel.com>
Diffstat (limited to 'BaseTools/Source/Python/BPDG')
-rw-r--r--BaseTools/Source/Python/BPDG/GenVpd.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/BaseTools/Source/Python/BPDG/GenVpd.py b/BaseTools/Source/Python/BPDG/GenVpd.py
index 807d0fa8d8..3bae803467 100644
--- a/BaseTools/Source/Python/BPDG/GenVpd.py
+++ b/BaseTools/Source/Python/BPDG/GenVpd.py
@@ -14,7 +14,7 @@
#
import Common.LongFilePathOs as os
-import StringIO
+from io import BytesIO
import StringTable as st
import array
import re
@@ -673,8 +673,8 @@ class GenVPD :
# Open failed
EdkLogger.error("BPDG", BuildToolError.FILE_OPEN_FAILURE, "File open failed for %s" % self.MapFileName, None)
- # Use a instance of StringIO to cache data
- fStringIO = StringIO.StringIO('')
+ # Use a instance of BytesIO to cache data
+ fStringIO = BytesIO('')
# Write the header of map file.
try :